@@ -34,6 +34,7 @@ pub struct Yozuk {
     skills: Vec<SkillCache>,
     labelers: Vec<Box<dyn Labeler>>,
     commands: Vec<Option<CommandCache>>,
+    redirections: Vec<(Vec<Token>, Vec<String>)>,
     logger: Logger,
 }
 
@@ -52,6 +53,27 @@ impl Yozuk {
     pub fn get_commands(&self, tokens: &[Token], streams: &[InputStream]) -> Vec<CommandArgs> {
         debug!(self.logger, "{:?}", tokens);
 
+        let filter = |(redirect, _): &&(Vec<Token>, Vec<String>)| {
+            redirect.len() == tokens.len()
+                && redirect
+                    .iter()
+                    .map(|token| token.as_utf8())
+                    .zip(tokens.iter().map(|token| token.as_utf8()))
+                    .all(|(a, b)| yozuk_helper_english::normalized_eq(a, [b], 0))
+        };
+
+        #[cfg(feature = "rayon")]
+        let redirection = self.redirections.par_iter().find_first(filter);
+
+        #[cfg(not(feature = "rayon"))]
+        let redirection = self.redirections.iter().find(filter);
+
+        if let Some((_, args)) = redirection {
+            return vec![CommandArgs::new()
+                .add_args(["yozuk-redirect"])
+                .add_args_iter(args)];
+        }
+
         let labeler = FeatureLabeler::new(&self.labelers);
 
         #[cfg(feature = "rayon")]
@@ -155,24 +177,39 @@ pub struct YozukBuilder {
     config: Config,
     i18n: I18n,
     logger: Logger,
+    redirections: Vec<(Vec<Token>, Vec<String>)>,
 }
 
 impl YozukBuilder {
-    pub fn logger(mut self, logger: Logger) -> Self {
+    pub fn set_logger(mut self, logger: Logger) -> Self {
         self.logger = logger;
         self
     }
 
-    pub fn config(mut self, config: Config) -> Self {
+    pub fn set_config(mut self, config: Config) -> Self {
         self.config = config;
         self
     }
 
-    pub fn i18n(mut self, i18n: I18n) -> Self {
+    pub fn set_i18n(mut self, i18n: I18n) -> Self {
         self.i18n = i18n;
         self
     }
 
+    pub fn add_redirection<T, TI, S, SI>(mut self, tokens: TI, args: SI) -> Self
+    where
+        T: Into<Token>,
+        TI: IntoIterator<Item = T>,
+        S: Into<String>,
+        SI: IntoIterator<Item = S>,
+    {
+        self.redirections.push((
+            tokens.into_iter().map(Into::into).collect(),
+            args.into_iter().map(Into::into).collect(),
+        ));
+        self
+    }
+
     pub fn build(self, model: ModelSet) -> Yozuk {
         let build_info = concat!(r#"{"version": ""#, env!("CARGO_PKG_VERSION"), r#""}"#);
 
@@ -242,6 +279,7 @@ impl YozukBuilder {
             skills,
             labelers,
             commands,
+            redirections: self.redirections,
             logger: self.logger,
         }
     }
@@ -253,6 +291,7 @@ impl Default for YozukBuilder {
             config: Default::default(),
             i18n: Default::default(),
             logger: NullLoggerBuilder.build().unwrap(),
+            redirections: Default::default(),
         }
     }
 }
